@@ -1,17 +1,16 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghijklmnopqrstuvwxyz~",
-  1: "abcdefhilmoprstuvy",
+  0: "abcdefghiklmnopqrstuvwxyz~",
+  1: "cfprsu",
   2: "l",
-  3: "abcdefghilmoprstuvy",
-  4: "_abcdefghijklmnopqrstuvw~",
-  5: "abcdefghiklmnopqrstuvwxy",
-  6: "bcdfhimoprst",
-  7: "abcdehilmnoprstwy",
-  8: "abcdefghiklmnoprstuvw",
-  9: "o",
-  10: "ailr",
-  11: "clmst"
+  3: "bcfgoprstu",
+  4: "abcdefghimnopqrstuv~",
+  5: "abcdefghklmnoprstuvwxy",
+  6: "bcdimt",
+  7: "acdfhlmnoprsty",
+  8: "abcdefghiklmnorstv",
+  9: "l",
+  10: "aclmrst"
 };
 
 var indexSectionNames =
@@ -25,9 +24,8 @@ var indexSectionNames =
   6: "typedefs",
   7: "enums",
   8: "enumvalues",
-  9: "related",
-  10: "defines",
-  11: "pages"
+  9: "defines",
+  10: "pages"
 };
 
 var indexSectionLabels =
@@ -41,8 +39,7 @@ var indexSectionLabels =
   6: "Typedefs",
   7: "Enumerations",
   8: "Enumerator",
-  9: "Friends",
-  10: "Macros",
-  11: "Pages"
+  9: "Macros",
+  10: "Pages"
 };
 
