@@ -6,9 +6,9 @@ var searchData=
   ['agcconstraint_3',['AgcConstraint',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html',1,'libcamera::ipa::AgcMeanLuminance']]],
   ['agcmeanluminance_4',['AgcMeanLuminance',['../classlibcamera_1_1ipa_1_1AgcMeanLuminance.html',1,'libcamera::ipa']]],
   ['algorithm_5',['Algorithm',['../classlibcamera_1_1ipa_1_1Algorithm.html',1,'libcamera::ipa']]],
-  ['algorithmfactory_6',['AlgorithmFactory',['../classlibcamera_1_1ipa_1_1AlgorithmFactory.html',1,'libcamera::ipa']]],
-  ['analoguegainconstants_7',['AnalogueGainConstants',['../unionlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainConstants.html',1,'libcamera::ipa::CameraSensorHelper']]],
-  ['analoguegainexpconstants_8',['AnalogueGainExpConstants',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainExpConstants.html',1,'libcamera::ipa::CameraSensorHelper']]],
-  ['analoguegainlinearconstants_9',['AnalogueGainLinearConstants',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinearConstants.html',1,'libcamera::ipa::CameraSensorHelper']]],
+  ['algorithm_3c_20module_20_3e_6',['Algorithm&lt; Module &gt;',['../classlibcamera_1_1ipa_1_1Algorithm.html',1,'libcamera::ipa']]],
+  ['algorithmfactory_7',['AlgorithmFactory',['../classlibcamera_1_1ipa_1_1AlgorithmFactory.html',1,'libcamera::ipa']]],
+  ['analoguegainexp_8',['AnalogueGainExp',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainExp.html',1,'libcamera::ipa::CameraSensorHelper']]],
+  ['analoguegainlinear_9',['AnalogueGainLinear',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinear.html',1,'libcamera::ipa::CameraSensorHelper']]],
   ['awb_10',['Awb',['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html',1,'libcamera::ipa::ipu3::algorithms']]]
 ];
