@@ -7,7 +7,7 @@ var indexSectionsWithContent =
   4: "_abcdefghijklmnopqrstuvwxyz~",
   5: "abcdefghiklmnopqrstuvwxy",
   6: "bcdfhimoprst",
-  7: "abcdehilmnoprstwy",
+  7: "abcdefhilmnoprstwy",
   8: "abcdefghiklmnoprstuvw",
   9: "o",
   10: "ailr",
